<?php
/**
 * Class definition file for the Point Of Marketing API responses
 *
 * Defines response constants and available response fields
 *
 * @package POMAPI
 * @author Jeremy Miller
 * @copyright 2015 Repeat Returns
 * @version 2.0.1
 * @since 2.0.0
 */
namespace POMAPI;

class POM_Response {
  const STATUS_OK = 200;
  const STATUS_CREATED = 201;
  const STATUS_MULTIPLE_CHOICES = 300;
  const STATUS_MOVED_PERMANENTLY = 301;
  const STATUS_BAD_REQUEST = 400;
  const STATUS_UNAUTHORIZED = 401;
  const STATUS_NOT_FOUND = 404;
  const STATUS_REQUEST_ENTITY_TOO_LARGE = 413;
  const STATUS_NOT_IMPLEMENTED = 501;
  const STATUS_SERVICE_UNAVAILABLE = 503;
  
  public $code;
  public $msg;
  public $object = false;
  public $id;
  public $url;
  public $remote_url = '';
  public $remote_payload = '';
  
  public function __construct($response) {
    $this->code = $response->code;
    $this->msg = isset($response->msg)?$response->msg:'';
    if (isset($response->chain)) {
      $this->object = new POM_Chain($response->chain);
    } else if (isset($response->members)) {
      $this->object = array();
      foreach ($response->members as $member) {
        $this->object[] = new POM_Member($member);
      }
    } else if (isset($response->member)) {
      $this->object = new POM_Member($response->member);
    } else if (isset($response->promotion)) {
      $this->object = new POM_Promotion($response->promotion);
    } else if (isset($response->store)) {
      $this->object = new POM_Store($response->store);
    } else if (isset($response->offers)) {
      $this->object = $response->offers;
    } else if (isset($response->stores)) {
      $this->object = $response->stores;
    } else if (isset($response->contents)) {
      $this->object = $response->contents;
    }
    if (isset($response->id)) {
      $this->id = $response->id;
    }
    if (isset($response->url)) {
      $this->url = $response->url;
    }
  }
}
?>